#[repr(i32)]pub enum SqlBackupState {
Unspecified = 0,
Enqueued = 1,
Running = 2,
Failed = 3,
Successful = 4,
Deleting = 5,
DeletionFailed = 6,
}Expand description
The backup’s state
Variants
Unspecified = 0
The state of the backup is unknown.
Enqueued = 1
The backup that’s added to a queue.
Running = 2
The backup is in progress.
Failed = 3
The backup failed.
Successful = 4
The backup is successful.
Deleting = 5
The backup is being deleted.
DeletionFailed = 6
Deletion of the backup failed.
Implementations
Sourceimpl SqlBackupState
impl SqlBackupState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.