#[repr(i32)]pub enum ExternalSyncParallelLevel {
Unspecified = 0,
Min = 1,
Optimal = 2,
Max = 3,
}Expand description
External Sync parallel level.
Variants
Unspecified = 0
Unknown sync parallel level. Will be defaulted to OPTIMAL.
Min = 1
Minimal parallel level.
Optimal = 2
Optimal parallel level.
Max = 3
Maximum parallel level.
Implementations
Sourceimpl ExternalSyncParallelLevel
impl ExternalSyncParallelLevel
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ExternalSyncParallelLevel.
Sourcepub fn from_i32(value: i32) -> Option<ExternalSyncParallelLevel>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ExternalSyncParallelLevel>
Converts an i32 to a ExternalSyncParallelLevel, or None if value is not a valid variant.
Sourceimpl ExternalSyncParallelLevel
impl ExternalSyncParallelLevel
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.