SqlDatabaseVersion

Enum SqlDatabaseVersion 

#[repr(i32)]
pub enum SqlDatabaseVersion {
Show 51 variants Unspecified = 0, Mysql51 = 2, Mysql55 = 3, Mysql56 = 5, Mysql57 = 6, Mysql80 = 20, Mysql8018 = 41, Mysql8026 = 85, Mysql8027 = 111, Mysql8028 = 132, Mysql8029 = 148, Mysql8030 = 174, Mysql8031 = 197, Mysql8032 = 213, Mysql8033 = 238, Mysql8034 = 239, Mysql8035 = 240, Mysql8036 = 241, Mysql8037 = 355, Mysql8039 = 357, Mysql8040 = 358, Mysql8041 = 488, Mysql8042 = 489, Mysql8043 = 553, Mysql8044 = 554, Mysql8045 = 555, Mysql8046 = 556, Mysql84 = 398, Mysql97 = 654, Sqlserver2017Standard = 11, Sqlserver2017Enterprise = 14, Sqlserver2017Express = 15, Sqlserver2017Web = 16, Postgres96 = 9, Postgres10 = 18, Postgres11 = 10, Postgres12 = 19, Postgres13 = 23, Postgres14 = 110, Postgres15 = 172, Postgres16 = 272, Postgres17 = 408, Postgres18 = 557, Sqlserver2019Standard = 26, Sqlserver2019Enterprise = 27, Sqlserver2019Express = 28, Sqlserver2019Web = 29, Sqlserver2022Standard = 199, Sqlserver2022Enterprise = 200, Sqlserver2022Express = 201, Sqlserver2022Web = 202,
}
The database engine type and version.

Variants



Unspecified = 0

This is an unknown database version.



Mysql51 = 2

👎Deprecated

The database version is MySQL 5.1.



Mysql55 = 3

👎Deprecated

The database version is MySQL 5.5.



Mysql56 = 5

The database version is MySQL 5.6.



Mysql57 = 6

The database version is MySQL 5.7.



Mysql80 = 20

The database version is MySQL 8.



Mysql8018 = 41

The database major version is MySQL 8.0 and the minor version is 18.



Mysql8026 = 85

The database major version is MySQL 8.0 and the minor version is 26.



Mysql8027 = 111

The database major version is MySQL 8.0 and the minor version is 27.



Mysql8028 = 132

The database major version is MySQL 8.0 and the minor version is 28.



Mysql8029 = 148

👎Deprecated

The database major version is MySQL 8.0 and the minor version is 29.



Mysql8030 = 174

The database major version is MySQL 8.0 and the minor version is 30.



Mysql8031 = 197

The database major version is MySQL 8.0 and the minor version is 31.



Mysql8032 = 213

The database major version is MySQL 8.0 and the minor version is 32.



Mysql8033 = 238

The database major version is MySQL 8.0 and the minor version is 33.



Mysql8034 = 239

The database major version is MySQL 8.0 and the minor version is 34.



Mysql8035 = 240

The database major version is MySQL 8.0 and the minor version is 35.



Mysql8036 = 241

The database major version is MySQL 8.0 and the minor version is 36.



Mysql8037 = 355

The database major version is MySQL 8.0 and the minor version is 37.



Mysql8039 = 357

The database major version is MySQL 8.0 and the minor version is 39.



Mysql8040 = 358

The database major version is MySQL 8.0 and the minor version is 40.



Mysql8041 = 488

The database major version is MySQL 8.0 and the minor version is 41.



Mysql8042 = 489

The database major version is MySQL 8.0 and the minor version is 42.



Mysql8043 = 553

The database major version is MySQL 8.0 and the minor version is 43.



Mysql8044 = 554

The database major version is MySQL 8.0 and the minor version is 44.



Mysql8045 = 555

The database major version is MySQL 8.0 and the minor version is 45.



Mysql8046 = 556

The database major version is MySQL 8.0 and the minor version is 46.



Mysql84 = 398

The database version is MySQL 8.4.



Mysql97 = 654

The database version is MySQL 9.7.



Sqlserver2017Standard = 11

The database version is SQL Server 2017 Standard.



Sqlserver2017Enterprise = 14

The database version is SQL Server 2017 Enterprise.



Sqlserver2017Express = 15

The database version is SQL Server 2017 Express.



Sqlserver2017Web = 16

The database version is SQL Server 2017 Web.



Postgres96 = 9

The database version is PostgreSQL 9.6.



Postgres10 = 18

The database version is PostgreSQL 10.



Postgres11 = 10

The database version is PostgreSQL 11.



Postgres12 = 19

The database version is PostgreSQL 12.



Postgres13 = 23

The database version is PostgreSQL 13.



Postgres14 = 110

The database version is PostgreSQL 14.



Postgres15 = 172

The database version is PostgreSQL 15.



Postgres16 = 272

The database version is PostgreSQL 16.



Postgres17 = 408

The database version is PostgreSQL 17.



Postgres18 = 557

The database version is PostgreSQL 18.



Sqlserver2019Standard = 26

The database version is SQL Server 2019 Standard.



Sqlserver2019Enterprise = 27

The database version is SQL Server 2019 Enterprise.



Sqlserver2019Express = 28

The database version is SQL Server 2019 Express.



Sqlserver2019Web = 29

The database version is SQL Server 2019 Web.



Sqlserver2022Standard = 199

The database version is SQL Server 2022 Standard.



Sqlserver2022Enterprise = 200

The database version is SQL Server 2022 Enterprise.



Sqlserver2022Express = 201

The database version is SQL Server 2022 Express.



Sqlserver2022Web = 202

The database version is SQL Server 2022 Web.

Implementations

Source

impl SqlDatabaseVersion

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of SqlDatabaseVersion.

pub fn from_i32(value: i32) -> Option<SqlDatabaseVersion>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a SqlDatabaseVersion, or None if value is not a valid variant.

Source

impl SqlDatabaseVersion

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.