BackupRun

Struct BackupRun 

pub struct BackupRun {
Show 19 fields pub kind: String, pub status: i32, pub enqueued_time: Option<Timestamp>, pub id: i64, pub start_time: Option<Timestamp>, pub end_time: Option<Timestamp>, pub error: Option<OperationError>, pub type: i32, pub description: String, pub window_start_time: Option<Timestamp>, pub instance: String, pub self_link: String, pub location: String, pub database_version: i32, pub disk_encryption_configuration: Option<DiskEncryptionConfiguration>, pub disk_encryption_status: Option<DiskEncryptionStatus>, pub backup_kind: i32, pub time_zone: String, pub max_chargeable_bytes: Option<i64>,
}
A BackupRun resource.

Fields

kind: String

This is always sql#backupRun.

status: i32

The status of this run.

enqueued_time: Option<Timestamp>

The time the run was enqueued in UTC timezone in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.

id: i64

The identifier for this backup run. Unique only for a specific Cloud SQL instance.

start_time: Option<Timestamp>

The time the backup operation actually started in UTC timezone in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.

end_time: Option<Timestamp>

The time the backup operation completed in UTC timezone in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.

error: Option<OperationError>

Information about why the backup operation failed. This is only present if the run has the FAILED status.

type: i32

The type of this run; can be either “AUTOMATED” or “ON_DEMAND” or “FINAL”. This field defaults to “ON_DEMAND” and is ignored, when specified for insert requests.

description: String

The description of this run, only applicable to on-demand backups.

window_start_time: Option<Timestamp>

The start time of the backup window during which this the backup was attempted in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.

instance: String

Name of the database instance.

self_link: String

The URI of this resource.

location: String

Location of the backups.

database_version: i32

Output only. The instance database version at the time this backup was made.

disk_encryption_configuration: Option<DiskEncryptionConfiguration>

Encryption configuration specific to a backup.

disk_encryption_status: Option<DiskEncryptionStatus>

Encryption status specific to a backup.

backup_kind: i32

Specifies the kind of backup, PHYSICAL or DEFAULT_SNAPSHOT.

time_zone: String

Backup time zone to prevent restores to an instance with a different time zone. Now relevant only for SQL Server.

max_chargeable_bytes: Option<i64>

Output only. The maximum chargeable bytes for the backup.

Implementations

Source

impl BackupRun

pub fn status(&self) -> SqlBackupRunStatus

Returns the enum value of status, or the default if the field is set to an invalid enum value.

pub fn set_status(&mut self, value: SqlBackupRunStatus)

Sets status to the provided enum value.

pub fn type(&self) -> SqlBackupRunType

Returns the enum value of type, or the default if the field is set to an invalid enum value.

pub fn set_type(&mut self, value: SqlBackupRunType)

Sets type to the provided enum value.

pub fn database_version(&self) -> SqlDatabaseVersion

Returns the enum value of database_version, or the default if the field is set to an invalid enum value.

pub fn set_database_version(&mut self, value: SqlDatabaseVersion)

Sets database_version to the provided enum value.

pub fn backup_kind(&self) -> SqlBackupKind

Returns the enum value of backup_kind, or the default if the field is set to an invalid enum value.

pub fn set_backup_kind(&mut self, value: SqlBackupKind)

Sets backup_kind to the provided enum value.

pub fn max_chargeable_bytes(&self) -> i64

Returns the value of max_chargeable_bytes, or the default value if max_chargeable_bytes is unset.