ConnectSettings

Struct ConnectSettings 

pub struct ConnectSettings {
Show 14 fields pub kind: String, pub server_ca_cert: Option<SslCert>, pub ip_addresses: Vec<IpMapping>, pub region: String, pub database_version: i32, pub backend_type: i32, pub psc_enabled: bool, pub dns_name: String, pub server_ca_mode: i32, pub custom_subject_alternative_names: Vec<String>, pub dns_names: Vec<DnsNameMapping>, pub node_count: Option<i32>, pub nodes: Vec<ConnectPoolNodeConfig>, pub mdx_protocol_support: Vec<i32>,
}
Connect settings retrieval response.

Fields

kind: String

This is always sql#connectSettings.

server_ca_cert: Option<SslCert>

SSL configuration.

ip_addresses: Vec<IpMapping>

The assigned IP addresses for the instance.

region: String

The cloud region for the instance. For example, us-central1, europe-west1. The region cannot be changed after instance creation.

database_version: i32

The database engine type and version. The databaseVersion field cannot be changed after instance creation. MySQL instances: MYSQL_8_0, MYSQL_5_7 (default), or MYSQL_5_6. PostgreSQL instances: POSTGRES_9_6, POSTGRES_10, POSTGRES_11, POSTGRES_12 (default), POSTGRES_13, or POSTGRES_14. SQL Server instances: SQLSERVER_2017_STANDARD (default), SQLSERVER_2017_ENTERPRISE, SQLSERVER_2017_EXPRESS, SQLSERVER_2017_WEB, SQLSERVER_2019_STANDARD, SQLSERVER_2019_ENTERPRISE, SQLSERVER_2019_EXPRESS, or SQLSERVER_2019_WEB.

backend_type: i32

SECOND_GEN: Cloud SQL database instance. EXTERNAL: A database server that is not managed by Google. This property is read-only; use the tier property in the settings object to determine the database type.

psc_enabled: bool

Whether PSC connectivity is enabled for this instance.

dns_name: String

The dns name of the instance.

server_ca_mode: i32

Specify what type of CA is used for the server certificate.

custom_subject_alternative_names: Vec<String>

Custom subject alternative names for the server certificate.

dns_names: Vec<DnsNameMapping>

Output only. The list of DNS names used by this instance.

node_count: Option<i32>

The number of read pool nodes in a read pool.

nodes: Vec<ConnectPoolNodeConfig>

Output only. Entries containing information about each read pool node of the read pool.

mdx_protocol_support: Vec<i32>

Optional. Output only. mdx_protocol_support controls how the client uses metadata exchange when connecting to the instance. The values in the list representing parts of the MDX protocol that are supported by this instance. When the list is empty, the instance does not support MDX, so the client must not send an MDX request. The default is empty.

Implementations

Source

impl ConnectSettings

pub fn database_version(&self) -> SqlDatabaseVersion

Returns the enum value of database_version, or the default if the field is set to an invalid enum value.

pub fn set_database_version(&mut self, value: SqlDatabaseVersion)

Sets database_version to the provided enum value.

pub fn backend_type(&self) -> SqlBackendType

Returns the enum value of backend_type, or the default if the field is set to an invalid enum value.

pub fn set_backend_type(&mut self, value: SqlBackendType)

Sets backend_type to the provided enum value.

pub fn server_ca_mode(&self) -> CaMode

Returns the enum value of server_ca_mode, or the default if the field is set to an invalid enum value.

pub fn set_server_ca_mode(&mut self, value: CaMode)

Sets server_ca_mode to the provided enum value.

pub fn mdx_protocol_support( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<MdxProtocolSupport>>

Returns an iterator which yields the valid enum values contained in mdx_protocol_support.

pub fn push_mdx_protocol_support(&mut self, value: MdxProtocolSupport)

Appends the provided enum value to mdx_protocol_support.

pub fn node_count(&self) -> i32

Returns the value of node_count, or the default value if node_count is unset.