Database

Struct Database 

pub struct Database {
    pub kind: String,
    pub charset: String,
    pub collation: String,
    pub etag: String,
    pub name: String,
    pub instance: String,
    pub self_link: String,
    pub project: String,
    pub database_details: Option<DatabaseDetails>,
}
Represents a SQL database on the Cloud SQL instance.

Fields

kind: String

This is always sql#database.

charset: String

The Cloud SQL charset value.

collation: String

The Cloud SQL collation value.

etag: String

This field is deprecated and will be removed from a future version of the API.

name: String

The name of the database in the Cloud SQL instance. This does not include the project ID or instance name.

instance: String

The name of the Cloud SQL instance. This does not include the project ID.

self_link: String

The URI of this resource.

project: String

The project ID of the project containing the Cloud SQL database. The Google apps domain is prefixed if applicable.

database_details: Option<DatabaseDetails>