pub struct FinalBackupConfig {
pub enabled: Option<bool>,
pub retention_days: Option<i32>,
}Expand description
Config used to determine the final backup settings for the instance.
Fields
enabled: Option<bool>Whether the final backup is enabled for the instance.
retention_days: Option<i32>The number of days to retain the final backup after the instance deletion. The final backup will be purged at (time_of_instance_deletion + retention_days).
Implementations