ImportContext

Struct ImportContext 

pub struct ImportContext {
    pub uri: String,
    pub database: String,
    pub kind: String,
    pub file_type: i32,
    pub csv_import_options: Option<SqlCsvImportOptions>,
    pub import_user: String,
    pub bak_import_options: Option<SqlBakImportOptions>,
    pub sql_import_options: Option<SqlImportOptions>,
    pub tde_import_options: Option<SqlTdeImportOptions>,
}
Database instance import context.

Fields

uri: String

Path to the import file in Cloud Storage, in the form gs://bucketName/fileName. Compressed gzip files (.gz) are supported when fileType is SQL. The instance must have write permissions to the bucket and read access to the file.

database: String

The target database for the import. If fileType is SQL, this field is required only if the import file does not specify a database, and is overridden by any database specification in the import file. For entire instance parallel import operations, the database is overridden by the database name stored in subdirectory name. If fileType is CSV, one database must be specified.

kind: String

This is always sql#importContext.

file_type: i32

The file type for the specified uri.`SQL: The file contains SQL statements. \CSV`: The file contains CSV data.

csv_import_options: Option<SqlCsvImportOptions>

Options for importing data as CSV.

import_user: String

The PostgreSQL user for this import operation. PostgreSQL instances only.

bak_import_options: Option<SqlBakImportOptions>

Import parameters specific to SQL Server .BAK files

sql_import_options: Option<SqlImportOptions>

Optional. Options for importing data from SQL statements.

tde_import_options: Option<SqlTdeImportOptions>

Optional. Import parameters specific to SQL Server TDE certificates

Implementations

Source

impl ImportContext

pub fn file_type(&self) -> SqlFileType

Returns the enum value of file_type, or the default if the field is set to an invalid enum value.

pub fn set_file_type(&mut self, value: SqlFileType)

Sets file_type to the provided enum value.