IpMapping

Struct IpMapping 

pub struct IpMapping {
    pub type: i32,
    pub ip_address: String,
    pub time_to_retire: Option<Timestamp>,
}
Database instance IP mapping

Fields

type: i32

The type of this IP address. A PRIMARY address is a public address that can accept incoming connections. A PRIVATE address is a private address that can accept incoming connections. An OUTGOING address is the source address of connections originating from the instance, if supported.

ip_address: String

The IP address assigned.

time_to_retire: Option<Timestamp>

The due time for this IP to be retired in RFC 3339 format, for example 2012-11-15T16:19:00.094Z. This field is only available when the IP is scheduled to be retired.

Implementations

Source

impl IpMapping

pub fn type(&self) -> SqlIpAddressType

Returns the enum value of type, or the default if the field is set to an invalid enum value.

pub fn set_type(&mut self, value: SqlIpAddressType)

Sets type to the provided enum value.