MaintenanceWindow

Struct MaintenanceWindow 

pub struct MaintenanceWindow {
    pub hour: Option<i32>,
    pub day: Option<i32>,
    pub update_track: i32,
    pub kind: String,
}
Maintenance window. This specifies when a Cloud SQL instance is restarted for system maintenance purposes.

Fields

hour: Option<i32>

Hour of day - 0 to 23. Specify in the UTC time zone.

day: Option<i32>

Day of week - MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, or SUNDAY. Specify in the UTC time zone. Returned in output as an integer, 1 to 7, where 1 equals Monday.

update_track: i32

Maintenance timing settings: canary, stable, or week5. For more information, see About maintenance on Cloud SQL instances.

kind: String

This is always sql#maintenanceWindow.

Implementations

Source

impl MaintenanceWindow

pub fn update_track(&self) -> SqlUpdateTrack

Returns the enum value of update_track, or the default if the field is set to an invalid enum value.

pub fn set_update_track(&mut self, value: SqlUpdateTrack)

Sets update_track to the provided enum value.