pub struct Operation {Show 20 fields
pub kind: String,
pub target_link: String,
pub status: i32,
pub user: String,
pub insert_time: Option<Timestamp>,
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub error: Option<OperationErrors>,
pub api_warning: Option<ApiWarning>,
pub operation_type: i32,
pub import_context: Option<ImportContext>,
pub export_context: Option<ExportContext>,
pub backup_context: Option<BackupContext>,
pub pre_check_major_version_upgrade_context: Option<PreCheckMajorVersionUpgradeContext>,
pub name: String,
pub target_id: String,
pub self_link: String,
pub target_project: String,
pub acquire_ssrs_lease_context: Option<AcquireSsrsLeaseContext>,
pub sub_operation_type: Option<SqlSubOperationType>,
}Expand description
An Operation resource. For successful operations that return an Operation resource, only the fields relevant to the operation are populated in the resource.
Fields
kind: StringThis is always sql#operation.
target_link: Stringstatus: i32The status of an operation.
user: StringThe email address of the user who initiated this operation.
insert_time: Option<Timestamp>The time this operation was enqueued in UTC timezone in RFC
3339 format, for example
2012-11-15T16:19:00.094Z.
start_time: Option<Timestamp>The time this operation actually started in UTC timezone in RFC
3339 format, for example
2012-11-15T16:19:00.094Z.
end_time: Option<Timestamp>The time this operation finished in UTC timezone in RFC
3339 format, for example
2012-11-15T16:19:00.094Z.
error: Option<OperationErrors>If errors occurred during processing of this operation, this field will be populated.
api_warning: Option<ApiWarning>An Admin API warning message.
operation_type: i32The type of the operation. Valid values are:
CREATEDELETEUPDATERESTARTIMPORTEXPORTBACKUP_VOLUMERESTORE_VOLUMECREATE_USERDELETE_USERCREATE_DATABASEDELETE_DATABASE
import_context: Option<ImportContext>The context for import operation, if applicable.
export_context: Option<ExportContext>The context for export operation, if applicable.
backup_context: Option<BackupContext>The context for backup operation, if applicable.
pre_check_major_version_upgrade_context: Option<PreCheckMajorVersionUpgradeContext>This field is only populated when the operation_type is PRE_CHECK_MAJOR_VERSION_UPGRADE. The PreCheckMajorVersionUpgradeContext message itself contains the details for that pre-check, such as the target database version for the upgrade and the results of the check (including any warnings or errors found).
name: StringAn identifier that uniquely identifies the operation. You can use this identifier to retrieve the Operations resource that has information about the operation.
target_id: StringName of the resource on which this operation runs.
self_link: StringThe URI of this resource.
target_project: StringThe project ID of the target instance related to this operation.
acquire_ssrs_lease_context: Option<AcquireSsrsLeaseContext>The context for acquire SSRS lease operation, if applicable.
sub_operation_type: Option<SqlSubOperationType>Optional. The sub operation based on the operation type.
Implementations
Sourceimpl Operation
impl Operation
Sourcepub fn status(&self) -> SqlOperationStatus
pub fn status(&self) -> SqlOperationStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: SqlOperationStatus)
pub fn set_status(&mut self, value: SqlOperationStatus)
Sets status to the provided enum value.
Sourcepub fn operation_type(&self) -> SqlOperationType
pub fn operation_type(&self) -> SqlOperationType
Returns the enum value of operation_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_operation_type(&mut self, value: SqlOperationType)
pub fn set_operation_type(&mut self, value: SqlOperationType)
Sets operation_type to the provided enum value.