pub struct PasswordValidationPolicy {
pub min_length: Option<i32>,
pub complexity: i32,
pub reuse_interval: Option<i32>,
pub disallow_username_substring: Option<bool>,
pub password_change_interval: Option<Duration>,
pub enable_password_policy: Option<bool>,
pub disallow_compromised_credentials: Option<bool>,
}Expand description
Database instance local user password validation policy. This message defines the password policy for local database users. When enabled, it enforces constraints on password complexity, length, and reuse. Keep this policy enabled to help prevent unauthorized access.
Fields
min_length: Option<i32>Minimum number of characters allowed.
complexity: i32The complexity of the password.
reuse_interval: Option<i32>Number of previous passwords that cannot be reused.
disallow_username_substring: Option<bool>Disallow username as a part of the password.
password_change_interval: Option<Duration>Minimum interval after which the password can be changed. This flag is only supported for PostgreSQL.
enable_password_policy: Option<bool>Whether to enable the password policy or not. When enabled, passwords must meet complexity requirements. Keep this policy enabled to help prevent unauthorized access. Disabling this policy allows weak passwords.
disallow_compromised_credentials: Option<bool>This field is deprecated and will be removed in a future version of the API.
Implementations
Sourceimpl PasswordValidationPolicy
impl PasswordValidationPolicy
Sourcepub fn complexity(&self) -> Complexity
pub fn complexity(&self) -> Complexity
Returns the enum value of complexity, or the default if the field is set to an invalid enum value.
Sourcepub fn set_complexity(&mut self, value: Complexity)
pub fn set_complexity(&mut self, value: Complexity)
Sets complexity to the provided enum value.