pub struct PointInTimeRestoreContext {
pub datasource: Option<String>,
pub point_in_time: Option<Timestamp>,
pub target_instance: Option<String>,
pub private_network: Option<String>,
pub allocated_ip_range: Option<String>,
pub preferred_zone: Option<String>,
pub preferred_secondary_zone: Option<String>,
}Expand description
The context to perform a point-in-time recovery of an instance managed by Backup and Disaster Recovery (DR) Service.
Fields
datasource: Option<String>The Backup and Disaster Recovery (DR) Service Datasource URI. Format: projects/{project}/locations/{region}/backupVaults/{backupvault}/dataSources/{datasource}.
point_in_time: Option<Timestamp>Required. The date and time to which you want to restore the instance.
target_instance: Option<String>Target instance name.
private_network: Option<String>Optional. The resource link for the VPC network from which the Cloud SQL
instance is accessible for private IP. For example,
/projects/myProject/global/networks/default.
allocated_ip_range: Option<String>Optional. The name of the allocated IP range for the internal IP Cloud SQL instance. For example: “google-managed-services-default”. If you set this, then Cloud SQL creates the IP address for the cloned instance in the allocated range. This range must comply with RFC 1035 standards. Specifically, the name must be 1-63 characters long and match the regular expression a-z?. Reserved for future use.
preferred_zone: Option<String>Optional. Point-in-time recovery of an instance to the specified zone. If no zone is specified, then clone to the same primary zone as the source instance.
preferred_secondary_zone: Option<String>Optional. Point-in-time recovery of a regional instance in the specified zones. If not specified, clone to the same secondary zone as the source instance. This value cannot be the same as the preferred_zone field.
Implementations
Sourceimpl PointInTimeRestoreContext
impl PointInTimeRestoreContext
Sourcepub fn datasource(&self) -> &str
pub fn datasource(&self) -> &str
Returns the value of datasource, or the default value if datasource is unset.
Sourcepub fn target_instance(&self) -> &str
pub fn target_instance(&self) -> &str
Returns the value of target_instance, or the default value if target_instance is unset.
Sourcepub fn private_network(&self) -> &str
pub fn private_network(&self) -> &str
Returns the value of private_network, or the default value if private_network is unset.
Sourcepub fn allocated_ip_range(&self) -> &str
pub fn allocated_ip_range(&self) -> &str
Returns the value of allocated_ip_range, or the default value if allocated_ip_range is unset.
Sourcepub fn preferred_zone(&self) -> &str
pub fn preferred_zone(&self) -> &str
Returns the value of preferred_zone, or the default value if preferred_zone is unset.
Sourcepub fn preferred_secondary_zone(&self) -> &str
pub fn preferred_secondary_zone(&self) -> &str
Returns the value of preferred_secondary_zone, or the default value if preferred_secondary_zone is unset.