pub struct PreCheckResponse {
pub message: Option<String>,
pub message_type: Option<i32>,
pub actions_required: Vec<String>,
}Expand description
Structured PreCheckResponse containing message, type, and required actions.
Fields
message: Option<String>The message to be displayed to the user.
message_type: Option<i32>The type of message whether it is an info, warning, or error.
actions_required: Vec<String>The actions that the user needs to take. Use repeated for multiple actions.
Implementations
Sourceimpl PreCheckResponse
impl PreCheckResponse
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
Returns the value of message, or the default value if message is unset.
Sourcepub fn message_type(&self) -> MessageType
pub fn message_type(&self) -> MessageType
Returns the enum value of message_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_message_type(&mut self, value: MessageType)
pub fn set_message_type(&mut self, value: MessageType)
Sets message_type to the provided enum value.