PscAutoConnectionConfig

Struct PscAutoConnectionConfig 

pub struct PscAutoConnectionConfig {
    pub consumer_project: String,
    pub consumer_network: String,
    pub ip_address: Option<String>,
    pub status: Option<String>,
    pub consumer_network_status: Option<String>,
}
Settings for an automatically-setup Private Service Connect consumer endpoint that is used to connect to a Cloud SQL instance.

Fields

consumer_project: String

Optional. This is the project ID of consumer service project of this consumer endpoint.

Optional. This is only applicable if consumer_network is a shared vpc network.

consumer_network: String

Optional. The consumer network of this consumer endpoint. This must be a resource path that includes both the host project and the network name.

For example, projects/project1/global/networks/network1.

The consumer host project of this network might be different from the consumer service project.

ip_address: Option<String>

The IP address of the consumer endpoint.

status: Option<String>

The connection status of the consumer endpoint.

consumer_network_status: Option<String>

The connection policy status of the consumer network.

Implementations

Source

impl PscAutoConnectionConfig

pub fn ip_address(&self) -> &str

Returns the value of ip_address, or the default value if ip_address is unset.

pub fn status(&self) -> &str

Returns the value of status, or the default value if status is unset.

pub fn consumer_network_status(&self) -> &str

Returns the value of consumer_network_status, or the default value if consumer_network_status is unset.