PscConfig

Struct PscConfig 

pub struct PscConfig {
    pub psc_enabled: Option<bool>,
    pub allowed_consumer_projects: Vec<String>,
    pub psc_auto_connections: Vec<PscAutoConnectionConfig>,
    pub network_attachment_uri: String,
}
PSC settings for a Cloud SQL instance.

Fields

psc_enabled: Option<bool>

Whether PSC connectivity is enabled for this instance.

allowed_consumer_projects: Vec<String>

Optional. The list of consumer projects that are allow-listed for PSC connections to this instance. This instance can be connected to with PSC from any network in these projects.

Each consumer project in this list may be represented by a project number (numeric) or by a project id (alphanumeric).

psc_auto_connections: Vec<PscAutoConnectionConfig>

Optional. The list of settings for requested Private Service Connect consumer endpoints that can be used to connect to this Cloud SQL instance.

network_attachment_uri: String

Optional. The network attachment of the consumer network that the Private Service Connect enabled Cloud SQL instance is authorized to connect via PSC interface. format: projects/PROJECT/regions/REGION/networkAttachments/ID

Implementations

Source

impl PscConfig

pub fn psc_enabled(&self) -> bool

Returns the value of psc_enabled, or the default value if psc_enabled is unset.