pub struct QueryResult {
pub columns: Vec<Column>,
pub rows: Vec<Row>,
pub message: String,
pub partial_result: bool,
pub status: Option<Status>,
}Expand description
QueryResult contains the result of executing a single SQL statement.
Fields
columns: Vec<Column>List of columns included in the result. This also includes the data type of the column.
rows: Vec<Row>Rows returned by the SQL statement.
message: StringMessage related to the SQL execution result.
partial_result: boolSet to true if the SQL execution’s result is truncated due to size limits or an error retrieving results.
status: Option<Status>If results were truncated due to an error, details of that error.