ReadPoolAutoScaleConfig

Struct ReadPoolAutoScaleConfig 

pub struct ReadPoolAutoScaleConfig {
    pub enabled: Option<bool>,
    pub min_node_count: Option<i32>,
    pub max_node_count: Option<i32>,
    pub target_metrics: Vec<TargetMetric>,
    pub disable_scale_in: Option<bool>,
    pub scale_in_cooldown_seconds: Option<i32>,
    pub scale_out_cooldown_seconds: Option<i32>,
}
The read pool auto-scale configuration.

Fields

enabled: Option<bool>

Indicates whether read pool auto scaling is enabled.

min_node_count: Option<i32>

Minimum number of read pool nodes to be maintained.

max_node_count: Option<i32>

Maximum number of read pool nodes to be maintained.

target_metrics: Vec<TargetMetric>

Optional. Target metrics for read pool auto scaling.

disable_scale_in: Option<bool>

Indicates whether read pool auto scaling supports scale in operations (removing nodes).

scale_in_cooldown_seconds: Option<i32>

The cooldown period for scale-in operations.

scale_out_cooldown_seconds: Option<i32>

The cooldown period for scale-out operations.

Implementations

Source

impl ReadPoolAutoScaleConfig

pub fn enabled(&self) -> bool

Returns the value of enabled, or the default value if enabled is unset.

pub fn min_node_count(&self) -> i32

Returns the value of min_node_count, or the default value if min_node_count is unset.

pub fn max_node_count(&self) -> i32

Returns the value of max_node_count, or the default value if max_node_count is unset.

pub fn disable_scale_in(&self) -> bool

Returns the value of disable_scale_in, or the default value if disable_scale_in is unset.

pub fn scale_in_cooldown_seconds(&self) -> i32

Returns the value of scale_in_cooldown_seconds, or the default value if scale_in_cooldown_seconds is unset.

pub fn scale_out_cooldown_seconds(&self) -> i32

Returns the value of scale_out_cooldown_seconds, or the default value if scale_out_cooldown_seconds is unset.