RestoreBackupContext

Struct RestoreBackupContext 

pub struct RestoreBackupContext {
    pub kind: String,
    pub backup_run_id: i64,
    pub instance_id: String,
    pub project: String,
}
Database instance restore from backup context. Backup context contains source instance id and project id.

Fields

kind: String

This is always sql#restoreBackupContext.

backup_run_id: i64

The ID of the backup run to restore from.

instance_id: String

The ID of the instance that the backup was taken from.

project: String

The full project ID of the source instance.