pub struct SqlActiveDirectoryConfig {
pub kind: String,
pub domain: String,
pub mode: i32,
pub dns_servers: Vec<String>,
pub admin_credential_secret_name: String,
pub organizational_unit: String,
}Expand description
Active Directory configuration, relevant only for Cloud SQL for SQL Server.
Fields
kind: StringThis is always sql#activeDirectoryConfig.
domain: StringThe name of the domain (e.g., mydomain.com).
mode: i32Optional. The mode of the Active Directory configuration.
dns_servers: Vec<String>Optional. Domain controller IPv4 addresses used to bootstrap Active Directory.
admin_credential_secret_name: StringOptional. The secret manager key storing the administrator credential. (e.g., projects/{project}/secrets/{secret}).
organizational_unit: StringOptional. The organizational unit distinguished name. This is the full hierarchical path to the organizational unit.
Implementations
Sourceimpl SqlActiveDirectoryConfig
impl SqlActiveDirectoryConfig
Sourcepub fn mode(&self) -> ActiveDirectoryMode
pub fn mode(&self) -> ActiveDirectoryMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: ActiveDirectoryMode)
pub fn set_mode(&mut self, value: ActiveDirectoryMode)
Sets mode to the provided enum value.