pub struct SqlUsersUpdateRequest {
pub host: String,
pub instance: String,
pub name: String,
pub project: String,
pub database_roles: Vec<String>,
pub revoke_existing_roles: Option<bool>,
pub body: Option<User>,
}Fields
host: StringOptional. Host of the user in the instance.
instance: StringDatabase instance ID. This does not include the project ID.
name: StringName of the user in the instance.
project: StringProject ID of the project that contains the instance.
database_roles: Vec<String>Optional. List of database roles to grant to the user. body.database_roles will be ignored for update request.
revoke_existing_roles: Option<bool>Optional. Specifies whether to revoke existing roles that are not present
in the database_roles field. If false or unset, the database roles
specified in database_roles are added to the user’s existing roles.
body: Option<User>Implementations
Sourceimpl SqlUsersUpdateRequest
impl SqlUsersUpdateRequest
Sourcepub fn revoke_existing_roles(&self) -> bool
pub fn revoke_existing_roles(&self) -> bool
Returns the value of revoke_existing_roles, or the default value if revoke_existing_roles is unset.