FinalBackupConfig

Struct FinalBackupConfig 

pub struct FinalBackupConfig {
    pub enabled: Option<bool>,
    pub retention_days: Option<i32>,
}
Config used to determine the final backup settings for the instance.

Fields

enabled: Option<bool>

Whether the final backup is enabled for the instance.

retention_days: Option<i32>

The number of days to retain the final backup after the instance deletion. The final backup will be purged at (time_of_instance_deletion + retention_days).

Implementations

Source

impl FinalBackupConfig

pub fn enabled(&self) -> bool

Returns the value of enabled, or the default value if enabled is unset.

pub fn retention_days(&self) -> i32

Returns the value of retention_days, or the default value if retention_days is unset.