pub struct OnPremisesConfiguration {
pub host_port: String,
pub kind: String,
pub username: String,
pub password: String,
pub ca_certificate: String,
pub client_certificate: String,
pub client_key: String,
pub dump_file_path: String,
pub source_instance: Option<InstanceReference>,
pub selected_objects: Vec<SelectedObjects>,
pub ssl_option: i32,
}Expand description
On-premises instance configuration.
Fields
host_port: StringThe host and port of the on-premises instance in host:port format
kind: StringThis is always sql#onPremisesConfiguration.
username: StringThe username for connecting to on-premises instance.
password: StringThe password for connecting to on-premises instance.
ca_certificate: StringPEM representation of the trusted CA’s x509 certificate.
client_certificate: StringPEM representation of the replica’s x509 certificate.
client_key: StringPEM representation of the replica’s private key. The corresponding public key is encoded in the client’s certificate.
dump_file_path: StringThe dump file to create the Cloud SQL replica.
source_instance: Option<InstanceReference>The reference to Cloud SQL instance if the source is Cloud SQL.
selected_objects: Vec<SelectedObjects>Optional. A list of objects that the user selects for replication from an external source instance.
ssl_option: i32Optional. SSL option for replica connection to the on-premises source.
Implementations
Sourceimpl OnPremisesConfiguration
impl OnPremisesConfiguration
Sourcepub fn ssl_option(&self) -> SslOption
pub fn ssl_option(&self) -> SslOption
Returns the enum value of ssl_option, or the default if the field is set to an invalid enum value.
Sourcepub fn set_ssl_option(&mut self, value: SslOption)
pub fn set_ssl_option(&mut self, value: SslOption)
Sets ssl_option to the provided enum value.