pub struct PerformanceCaptureConfig {
pub enabled: Option<bool>,
pub probing_interval_seconds: Option<i32>,
pub probe_threshold: Option<i32>,
pub running_threads_threshold: Option<i32>,
pub seconds_behind_source_threshold: Option<i32>,
pub transaction_duration_threshold: Option<i32>,
}Expand description
Performance Capture configuration.
Fields
enabled: Option<bool>Optional. Enable or disable the Performance Capture feature.
probing_interval_seconds: Option<i32>Optional. The time interval in seconds between any two probes.
probe_threshold: Option<i32>Optional. The minimum number of consecutive readings above threshold that triggers instance state capture.
running_threads_threshold: Option<i32>Optional. The minimum number of server threads running to trigger the capture on primary.
seconds_behind_source_threshold: Option<i32>Optional. The minimum number of seconds replica must be lagging behind primary to trigger capture on replica.
transaction_duration_threshold: Option<i32>Optional. The amount of time in seconds that a transaction needs to have been open before the watcher starts recording it.
Implementations
Sourceimpl PerformanceCaptureConfig
impl PerformanceCaptureConfig
Sourcepub fn enabled(&self) -> bool
pub fn enabled(&self) -> bool
Returns the value of enabled, or the default value if enabled is unset.
Sourcepub fn probing_interval_seconds(&self) -> i32
pub fn probing_interval_seconds(&self) -> i32
Returns the value of probing_interval_seconds, or the default value if probing_interval_seconds is unset.
Sourcepub fn probe_threshold(&self) -> i32
pub fn probe_threshold(&self) -> i32
Returns the value of probe_threshold, or the default value if probe_threshold is unset.
Sourcepub fn running_threads_threshold(&self) -> i32
pub fn running_threads_threshold(&self) -> i32
Returns the value of running_threads_threshold, or the default value if running_threads_threshold is unset.
Sourcepub fn seconds_behind_source_threshold(&self) -> i32
pub fn seconds_behind_source_threshold(&self) -> i32
Returns the value of seconds_behind_source_threshold, or the default value if seconds_behind_source_threshold is unset.
Sourcepub fn transaction_duration_threshold(&self) -> i32
pub fn transaction_duration_threshold(&self) -> i32
Returns the value of transaction_duration_threshold, or the default value if transaction_duration_threshold is unset.